'use strict';

/**
 * 作者: 于亚东 - Adam Yu
 * 邮箱: 106395181@qq.com 
 */

/**
 * @ngdoc service
 * @name wangfan.ApiService
 * @description
 * # ApiService
 * Retrieves correct api to make requests against.
 * Uses settings from API_ENDPOINT defined in /config/apiEndpoint.js
 *
 * Usage example: $http({
 *                      url: ApiService.getEndpoint() + '/things',
 *                      method: 'GET'
 *                 })
 *
 */
angular.module('wangfan')

// Cookie
.factory('Cookie', function() {

	return {

		set: function(key, value) {

			var Days = 30;
			var exp = new Date();

						exp.setTime(exp.getTime() + 24 * 60 * 60 * 1000);

						document.cookie = key + "=" + value + ";expires=" + exp.toGMTString();
//			document.cookie = key + "=" + value;

		},
		get: function(key) {

			var arr = document.cookie.match(new RegExp("(^| )" + key + "=([^;]*)(;|$)"));

			if (arr != null) {
				return (arr[2]);
			} else {
				return "";
			}

		},
		remove: function(key) {

			var exp = new Date();
			exp.setTime(exp.getTime() + (-1 * 24 * 60 * 60 * 1000));
			var cval = this.set(key);
			document.cookie = key + "=" + cval + "; expires=" + exp.toGMTString();

		}

	}

})

// Storage
.factory('Storage', function() {

	return {

		set: function(key, data) {

			return window.localStorage.setItem(key, window.JSON.stringify(data));

		},
		get: function(key) {

			return window.JSON.parse(window.localStorage.getItem(key));

		},
		remove: function(key) {

			return window.localStorage.removeItem(key);

		}

	}

})

// 广告服务
.factory('AdsService', function($rootScope, $http) {

	// API 数据接口
	var ApiUrl = 'data/banner/banner',
		// 存储数据结构，包含了下一页、是否有下一页的属性
		storage = {};

	// 获取第一页数据
	function getInitStorage() {

		$http.get(ApiUrl + '?t=' + Date.parse(new Date()))
			.success(function(data) {

				// 存储数据
				storage = {
					result: data
				}

				// 数据请求完成以后，通知 controller
				$rootScope.$broadcast('Ads.Updated');

			})

	}

	// 获取保存数据
	function getStorage() {

		// 解决异步加载数据没有完成
		if (storage == undefined) {
			return false;
		}

		return storage.result;

	}

	return {
		// 获取第一页数据
		getStorage: getStorage,
		// 获取保存数据
		getInitStorage: getInitStorage
	}

})

// 新闻服务
.factory('HomeService', function($rootScope, $http) {

	// API 数据接口
	var ApiUrl = 'data/index/index',
		// 存储数据结构，包含了下一页、是否有下一页的属性
		storage = {};

	// 获取第一页数据
	function getInitStorage() {

		$http.get(ApiUrl + '?t=' + Date.parse(new Date()))
			.success(function(data) {

				// 存储数据
				storage = {
					result: data
				}

				// 数据请求完成以后，通知 controller
				$rootScope.$broadcast('Home.Updated');

			})

	}

	// 获取保存数据
	function getStorage() {

		// 解决异步加载数据没有完成
		if (storage == undefined) {
			return false;
		}

		return storage.result;

	}

	return {
		// 获取第一页数据
		getStorage: getStorage,
		// 获取保存数据
		getInitStorage: getInitStorage
	}

})

// 新闻分类导航
.factory('ArticleCatidService', function($rootScope, $http) {
	// 声明常用变量
	var ApiURL = 'data/news/nav',
		// 存储数据容器
		storage = {};

	$rootScope.endPage = true;

	// 获取存储数据容器
	function getStorage() {

		$http.get(ApiURL + '?t=' + Date.parse(new Date())).success(function(data) {

			// 异步请求数据存储到storage容器中
			storage = {
				cateIdNav: data
			}

			// 接收服务传过来的广播通知，解决异步请求问题
			$rootScope.$broadcast('ArticleCatid.Updated');

		});

		return storage;

	}

	// 获取分类导航
	function getCatid() {

		return storage.cateIdNav;

	}

	// 服务应用程序接口
	return {
		getStorage: getStorage,
		getCatid: getCatid
	}

})

// 新闻服务
.factory('ArticleService', function($rootScope, $http, API_ENDPOINT) {

	// API 数据接口
	var ApiUrl = 'data/news/list/',
		// 分类ID
		cateId = -1,
		// 显示多少条数据
		nextPage = 1,
		// 存储数据结构，包含了下一页、是否有下一页的属性
		storage = {},

		pageNumber = {};

	// 获取第一页数据
	function getInitStorage() {

		// 是否有下一页
		var hasNextPage = true;

		$http.get(ApiUrl + cateId + '/' + nextPage + '?t=' + Date.parse(new Date()))
			.success(function(data) {

				//不存在下一页
				if (data.length < API_ENDPOINT.articlePageSize) {
					hasNextPage = false;
				}

				// 存在下一页，存储数据
				storage = {
					hasNextPage: hasNextPage,
					nextPage: 2,
					result: data
				}

				console.log(storage.result);

				// 数据请求完成以后，通知 controller
				$rootScope.$broadcast('Article.Updated');

			})
			.error(function() {

				$rootScope.endPage = false;

			})

	}

	// 获取保存数据
	function getStorage() {

		// 解决异步加载数据没有完成
		if (storage == undefined) {
			return false;
		}

		return storage.result;

	}

	// 获取更多数据
	function getMoreStorage() {

		// 为了解决一步加载的时候数据还没有加载完成  然后请求loadMore的时候  找不到数据
		if (storage === undefined) {
			return false;
		}

		// 获取以前的数据
		var hasNextPage = storage.hasNextPage;
		var nextPage = storage.nextPage;
		var morestorageData = storage.result;

		console.log(morestorageData);

		$http.get(ApiUrl + cateId + '/' + nextPage + '?t=' + Date.parse(new Date()))
			.success(function(data) {

				// 连接存储对象
				morestorageData = morestorageData.concat(data);

				console.log(morestorageData)

				//不存在下一页
				if (data.length < API_ENDPOINT.articlePageSize) {
					hasNextPage = false;
				}

				// 存在下一页，存储数据
				storage = {
					hasNextPage: hasNextPage,
					nextPage: nextPage,
					result: morestorageData
				}

				// 数据请求完成以后，通知 controller
				$rootScope.$broadcast('Article.Updated');

			})
			.error(function() {

				$rootScope.endPage = false;

			})

		nextPage++;

	}

	function setStorage(cate_id) {

		// 动态设置分类 ID
		cateId = cate_id;

		// 重新调用接口页面
		this.getInitStorage();

	}

	// 判断是否有下一页
	function hasNextPage() {

		if (storage === undefined) {
			return false;
		}

		return storage.hasNextPage;

	}

	return {
		// 获取第一页数据
		getStorage: getStorage,
		// 写入分类数据
		setStorage: setStorage,
		// 获取保存数据
		getInitStorage: getInitStorage,
		// 获取更多数据
		getMoreStorage: getMoreStorage,
		// 判断是否有下一页
		hasNextPage: hasNextPage
	}

})

// 新闻工厂服务
.factory('ArticleDetailService', function($rootScope, $http) {

	var ApiUrl,
		// 存储数据结构
		storage = {};

	// 获取第一页数据
	function getTimestampId(url, timestamp, id) {

		ApiUrl = url;

		$http.get(ApiUrl + timestamp + '/' + id + '?t=' + Date.parse(new Date()))
			.success(function(data) {

				// 存储数据
				storage = {
					result: data
				}

				$rootScope.$broadcast('ArticleDetail.Updated');

			})
			.error(function(){
				storage = {};
				$rootScope.$broadcast('ArticleDetail.Updated');
			})

	}

	// 获取新闻存储数据
	function getStorage() {

		return storage.result;

	}

	return {

		// 获取新闻接口内容
		getTimestampId: getTimestampId,
		// 获取新闻存储数据
		getStorage: getStorage

	}

})

.factory('MovieService', function($rootScope, $http) {

	// API 数据接口
	var ApiUrl = 'data/video/list/',
		// 分类ID
		cateId = 1,
		// 显示多少条数据
		nextPage = 1,
		// 存储数据结构，包含了下一页、是否有下一页的属性
		storage = {};

	// 获取第一页数据
	function getInitStorage() {

		// 是否有下一页
		var hasNextPage = true;
		console.log(ApiUrl + nextPage);
		$http.get(ApiUrl + nextPage + '?t=' + Date.parse(new Date()))
			.success(function(data) {

				//不存在下一页
				if (data.length < 20) {
					hasNextPage = false;
				}

				// 存在下一页，存储数据
				storage[cateId] = {
					hasNextPage: hasNextPage,
					nextPage: 2,
					result: data
				}

				//				console.log(storage[cateId].result);

				// 数据请求完成以后，通知 controller
				$rootScope.$broadcast('Movie.Updated');

			})
			.error(function() {

				$rootScope.endPage = false;

			})

	}

	// 获取保存数据
	function getStorage() {

		// 解决异步加载数据没有完成
		if (storage[cateId] == undefined) {
			return false;
		}

		return storage[cateId].result;

	}

	// 获取更多数据
	function getMoreStorage() {

		// 为了解决一步加载的时候数据还没有加载完成  然后请求loadMore的时候  找不到数据
		if (storage[cateId] === undefined) {
			return false;
		}

		// 获取以前的数据
		var hasNextPage = storage[cateId].hasNextPage;
		var nextPage = storage[cateId].nextPage;
		var morestorageData = storage[cateId].result;

		console.log(morestorageData);

		$http.get(ApiUrl + nextPage + '?t=' + Date.parse(new Date()))
			.success(function(data) {

				// 连接存储对象
				morestorageData = morestorageData.concat(data);

				console.log(morestorageData)

				//不存在下一页
				if (data.length < 20) {
					hasNextPage = false;
				}

				// 存在下一页，存储数据
				storage[cateId] = {
					hasNextPage: hasNextPage,
					nextPage: nextPage,
					result: morestorageData
				}

				// 数据请求完成以后，通知 controller
				$rootScope.$broadcast('Movie.Updated');

			})
			.error(function() {

				$rootScope.endPage = false;

			})

		nextPage++;

	}

	function setStorage(cate_id) {

		// 动态设置分类 ID
		cateId = cate_id;

		// 重新调用接口页面
		this.getInitStorage();

	}

	// 判断是否有下一页
	function hasNextPage() {

		if (storage[cateId] === undefined) {
			return false;
		}

		return storage[cateId].hasNextPage;

	}

	return {
		// 获取第一页数据
		getStorage: getStorage,
		// 写入分类数据
		setStorage: setStorage,
		// 获取保存数据
		getInitStorage: getInitStorage,
		// 获取更多数据
		getMoreStorage: getMoreStorage,
		// 判断是否有下一页
		hasNextPage: hasNextPage
	}

})

// 影视工厂服务
.factory('MovieDetailService', function($rootScope, $http) {

	var ApiUrl,
		// 存储数据结构
		storage = {};

	// 获取第一页数据
	function getTimestampId(url, timestamp, id) {

		ApiUrl = url;

		$http.get(ApiUrl + timestamp + '/' + id + '?t=' + Date.parse(new Date()))
			.success(function(data) {

				// 存储数据
				storage = {
					result: data
				}

				$rootScope.$broadcast('MovieDetail.Updated');

			})
			.error(function(){
				storage = {};
				$rootScope.$broadcast('MovieDetail.Updated');
			})

	}

	// 获取影视存储数据
	function getStorage() {

		return storage.result;

	}

	return {

		// 获取影视接口内容
		getTimestampId: getTimestampId,
		// 获取影视存储数据
		getStorage: getStorage

	}

})

.factory('NovelService', function($rootScope, $http, API_ENDPOINT) {

	// API 数据接口
	var ApiUrl = 'data/novel/list/',
		// 分类ID
		cateId = 1,
		// 显示多少条数据
		nextPage = 1,
		// 显示条数
		pageSize = API_ENDPOINT.novelPageSize,
		// 存储数据结构，包含了下一页、是否有下一页的属性
		storage = {};

	// 获取第一页数据
	function getInitStorage() {

		// 是否有下一页
		var hasNextPage = true;
		console.log(ApiUrl + nextPage);
		$http.get(ApiUrl + nextPage + '?t=' + Date.parse(new Date()))
			.success(function(data) {

				//不存在下一页
				if (data.length < pageSize) {
					hasNextPage = false;
				}

				// 存在下一页，存储数据
				storage[cateId] = {
					hasNextPage: hasNextPage,
					nextPage: 2,
					result: data
				}

				console.log(storage[cateId].result);

				// 数据请求完成以后，通知 controller
				$rootScope.$broadcast('Novel.Updated');

			})
			.error(function() {

				$rootScope.endPage = false;

			})

	}

	// 获取保存数据
	function getStorage() {

		// 解决异步加载数据没有完成
		if (storage[cateId] == undefined) {
			return false;
		}

		return storage[cateId].result;

	}

	// 获取更多数据
	function getMoreStorage() {

		// 为了解决一步加载的时候数据还没有加载完成  然后请求loadMore的时候  找不到数据
		if (storage[cateId] === undefined) {
			return false;
		}

		// 获取以前的数据
		var hasNextPage = storage[cateId].hasNextPage;
		var nextPage = storage[cateId].nextPage;
		var morestorageData = storage[cateId].result;

		console.log(morestorageData);

		$http.get(ApiUrl + nextPage + '?t=' + Date.parse(new Date()))
			.success(function(data) {

				// 连接存储对象
				morestorageData = morestorageData.concat(data);

				console.log(morestorageData);

				//不存在下一页
				if (data.length < pageSize) {
					hasNextPage = false;
				}

				// 存在下一页，存储数据
				storage[cateId] = {
					hasNextPage: hasNextPage,
					nextPage: nextPage,
					result: morestorageData
				}

				// 数据请求完成以后，通知 controller
				$rootScope.$broadcast('Novel.Updated');

			})
			.error(function() {

				$rootScope.endPage = false;

			})

		nextPage++;

	}

	function setStorage(cate_id) {

		// 动态设置分类 ID
		cateId = cate_id;

		// 重新调用接口页面
		this.getInitStorage();

	}

	// 判断是否有下一页
	function hasNextPage() {

		if (storage[cateId] === undefined) {
			return false;
		}

		return storage[cateId].hasNextPage;

	}

	return {
		// 获取第一页数据
		getStorage: getStorage,
		// 写入分类数据
		setStorage: setStorage,
		// 获取保存数据
		getInitStorage: getInitStorage,
		// 获取更多数据
		getMoreStorage: getMoreStorage,
		// 判断是否有下一页
		hasNextPage: hasNextPage
	}

})

// 小说工厂服务
.factory('NovelDetailService', function($rootScope, $http) {

	var ApiUrl,
		// 存储数据结构
		storage = {};

	// 获取第一页数据
	function getTimestampId(url, timestamp, id) {

		ApiUrl = url;

		$http.get(ApiUrl + timestamp + '/' + id + '?t=' + Date.parse(new Date()))
			.success(function(data) {

				// 存储数据
				storage = {
					result: data
				}

				$rootScope.$broadcast('NovelDetail.Updated');

			})
			.error(function(){
				storage = {};
				$rootScope.$broadcast('NovelDetail.Updated');
			})

	}

	// 获取小说存储数据
	function getStorage() {

		return storage.result;

	}

	return {

		// 获取小说接口内容
		getTimestampId: getTimestampId,
		// 获取小说存储数据
		getStorage: getStorage

	}

})

// 小说工厂服务
.factory('NovelContentService', function($rootScope, $http) {

	var ApiUrl,
		// 存储数据结构
		storage = {};

	// 获取第一页数据
	function getTimestampId(url, novelId, id) {

		ApiUrl = url;

		$http.get(ApiUrl + "/" + novelId + '/' + id + '?t=' + Date.parse(new Date()))
			.success(function(data) {

				// 存储数据
				storage = {
					result: data
				}

				$rootScope.$broadcast('NovelContent.Updated');

			})

	}

	// 获取小说存储数据
	function getStorage() {

		return storage.result;

	}

	return {

		// 获取小说接口内容
		getTimestampId: getTimestampId,
		// 获取小说存储数据
		getStorage: getStorage

	}

})


//用户打点服务
.factory('RecordDataService', function($http, $location, Cookie) {
	//用户打点
	function recordData(hitID) {
		if(IsApp){
			var ua = navigator.userAgent;
			if(ua.indexOf('iOSApp/wangfan') >= 0) {
				var url = 'iwangfan://hit?' + hitID + '&uID=' + getCookie('userId') + version + appHitLog;
				var iframe = document.createElement("iframe");
			    iframe.src = url;
			    setTimeout(function(){
			   		var ifs = document.getElementsByTagName("iframe");
			   		for(var i=0;i<ifs.length;i++){
			   			document.body.removeChild(ifs[i])
			   		}
			   	},10);
			    document.body.appendChild(iframe);
			}else{
				var myDate = Date.parse(new Date());
				$.get('hit?' + hitID + '&uID=' + getCookie('userId') + version + appHitLog +'&t=' + myDate,function(){});
			}
		}
		var apiUrl='http://www.wangfanwifi.com:16621/api/hit?';
		var myDate = Date.parse(new Date());
		$http.get(apiUrl + hitID + '&uID=' + Cookie.get('userId') + version + appHitLog +'&t=' + myDate)
			.success(function() {})
	}
	return {

		recordData: recordData

	}
})
.factory('HomeArticleService', function($http, $rootScope) {
	var ApiUrl = 'data/news/list/',
		// 分类ID
		cateId = -1,
		// 显示多少条数据
		nextPage = 1,
		// 存储数据结构，包含了下一页、是否有下一页的属性
		storage = {};

	function getInitStorage() {
		$http.get(ApiUrl + cateId + '/' + nextPage + '?t=' + Date.parse(new Date()))
			.success(function(data) {
				storage = {
					result: data
				}
				$rootScope.$broadcast('HomeArticle.Updated');
			})
	}

	function getStorage() {

		// 解决异步加载数据没有完成
		if (storage == undefined) {
			return false;
		}
		return storage.result;

	}
	return {
		getInitStorage: getInitStorage,
		getStorage: getStorage
	}
})
//h5游戏
.factory('H5GameService', function($rootScope, $http, API_ENDPOINT) {

		// API 数据接口
		var ApiUrl = 'data/topic/game/list/',
			// 分类ID
			type = 1200,
			// 显示多少条数据
			nextPage = 1,
			// 存储数据结构，包含了下一页、是否有下一页的属性
			storage = {};

		// 获取第一页数据
		function getInitStorage() {

			// 是否有下一页
			var hasNextPage = true;

			$http.get(ApiUrl + '/' + nextPage + '?t=' + Date.parse(new Date()))
				.success(function(data) {

					//不存在下一页
					if (data.length < API_ENDPOINT.appPageSize) {
						hasNextPage = false;
					}

					// 存在下一页，存储数据
					storage[type] = {
						hasNextPage: hasNextPage,
						nextPage: 2,
						result: data
					}

					console.log(storage[type].result);

					// 数据请求完成以后，通知 controller
					$rootScope.$broadcast('H5Game.Updated');

				})
				.error(function() {

					$rootScope.endPage = false;

				})

		}

		// 获取保存数据
		function getStorage() {

			// 解决异步加载数据没有完成
			if (storage[type] == undefined) {
				return false;
			}

			return storage[type].result;

		}

		// 获取更多数据
		function getMoreStorage() {

			// 为了解决一步加载的时候数据还没有加载完成  然后请求loadMore的时候  找不到数据
			if (storage[type] === undefined) {
				return false;
			}

			// 获取以前的数据
			var hasNextPage = storage[type].hasNextPage;
			var nextPage = storage[type].nextPage;
			var morestorageData = storage[type].result;

			console.log(morestorageData);

			$http.get(ApiUrl + type + '/' + nextPage + '?t=' + Date.parse(new Date()))
				.success(function(data) {

					if (data.length < API_ENDPOINT.appPageSize) {
						hasNextPage = false;
					}

					// 连接存储对象
					morestorageData = morestorageData.concat(data);

					console.log(morestorageData);

					if (data.length < API_ENDPOINT.appPageSize) {
						hasNextPage = false;
					}

					// 存在下一页，存储数据
					storage[type] = {
						hasNextPage: hasNextPage,
						nextPage: nextPage,
						result: morestorageData
					}

					// 数据请求完成以后，通知 controller
					$rootScope.$broadcast('H5Game.Updated');

				})
				.error(function() {

					$rootScope.endPage = false;

				})

			nextPage++;

		}

		function setStorage(cate_id) {

			// 动态设置分类 ID
			type = cate_id;

			// 重新调用接口页面
			this.getInitStorage();

		}

		// 判断是否有下一页
		function hasNextPage() {

			if (storage[type] === undefined) {
				return false;
			}

			return storage[type].hasNextPage;

		}

		return {
			// 获取第一页数据
			getStorage: getStorage,
			// 写入分类数据
			setStorage: setStorage,
			// 获取保存数据
			getInitStorage: getInitStorage,
			// 获取更多数据
			getMoreStorage: getMoreStorage,
			// 判断是否有下一页
			hasNextPage: hasNextPage
		}

	})

//应用服务
	.factory('AppService', function($rootScope, $http, API_ENDPOINT) {

		// API 数据接口
		var ApiUrl = 'data/apps/list/',
		// 分类ID
			type = 1201,
		// 显示多少条数据
			nextPage = 1,
		// 存储数据结构，包含了下一页、是否有下一页的属性
			storage = {};

		// 获取第一页数据
		function getInitStorage() {

			// 是否有下一页
			var hasNextPage = true;

			$http.get(ApiUrl + type + '/' + nextPage + '?t=' + Date.parse(new Date()))
				.success(function(data) {
					if (data.length < API_ENDPOINT.appPageSize) {
						hasNextPage = false;
					}

					// 存在下一页，存储数据
					storage[type] = {
						hasNextPage: hasNextPage,
						nextPage: 2,
						result: data
					}

					console.log(storage[type].result);

					// 数据请求完成以后，通知 controller
					$rootScope.$broadcast('App.Updated');

				})
				.error(function() {

					$rootScope.endPage = false;

				})

		}

		// 获取保存数据
		function getStorage() {

			// 解决异步加载数据没有完成
			if (storage[type] == undefined) {
				return false;
			}

			return storage[type].result;

		}

		// 获取更多数据
		function getMoreStorage() {

			// 为了解决一步加载的时候数据还没有加载完成  然后请求loadMore的时候  找不到数据
			if (storage[type] === undefined) {
				return false;
			}

			// 获取以前的数据
			var hasNextPage = storage[type].hasNextPage;
			var nextPage = storage[type].nextPage;
			var morestorageData = storage[type].result;

			console.log(morestorageData);

			$http.get(ApiUrl + type + '/' + nextPage + '?t=' + Date.parse(new Date()))
				.success(function(data) {

					// 连接存储对象
					morestorageData = morestorageData.concat(data);

					console.log(morestorageData)

					//不存在下一页
					if (data.length < API_ENDPOINT.appPageSize) {
						hasNextPage = false;
					}

					// 存在下一页，存储数据
					storage[type] = {
						hasNextPage: hasNextPage,
						nextPage: nextPage,
						result: morestorageData
					}

					// 数据请求完成以后，通知 controller
					$rootScope.$broadcast('App.Updated');

				})
				.error(function() {

					$rootScope.endPage = false;

				})

			nextPage++;

		}

		function setStorage(cate_id) {

			// 动态设置分类 ID
			type = cate_id;

			// 重新调用接口页面
			this.getInitStorage();

		}

		// 判断是否有下一页
		function hasNextPage() {

			if (storage[type] === undefined) {
				return false;
			}

			return storage[type].hasNextPage;

		}

		return {
			// 获取第一页数据
			getStorage: getStorage,
			// 写入分类数据
			setStorage: setStorage,
			// 获取保存数据
			getInitStorage: getInitStorage,
			// 获取更多数据
			getMoreStorage: getMoreStorage,
			// 判断是否有下一页
			hasNextPage: hasNextPage
		}

	})
	// 应用工厂服务
	.factory('AppDetailService', function($rootScope, $http) {

		var ApiUrl,
		// 存储数据结构
			storage = {};

		// 获取第一页数据
		function getTimestampId(url, timestamp, id) {

			ApiUrl = url;

			$http.get(ApiUrl + timestamp + '/' + id + '?t=' + Date.parse(new Date()))
				.success(function(data) {

					// 存储数据
					storage = {
						result: data
					}

					$rootScope.$broadcast('AppDetail.Updated');

				})
				.error(function(){
					storage = {};
					$rootScope.$broadcast('AppDetail.Updated');
				})

		}

		// 获取应用存储数据
		function getStorage() {

			return storage.result;

		}

		return {

			// 获取应用接口内容
			getTimestampId: getTimestampId,
			// 获取应用存储数据
			getStorage: getStorage

		}

	})
	//游戏数据
	.factory('GameService', function($rootScope, $http, API_ENDPOINT) {

		// API 数据接口
		var ApiUrl = 'data/apps/list/',
		// 分类ID
			type = 1200,
		// 显示多少条数据
			nextPage = 1,
		// 存储数据结构，包含了下一页、是否有下一页的属性
			storage = {};

		// 获取第一页数据
		function getInitStorage() {

			// 是否有下一页
			var hasNextPage = true;

			$http.get(ApiUrl + type + '/' + nextPage + '?t=' + Date.parse(new Date()))
				.success(function(data) {

					//不存在下一页
					if (data.length < API_ENDPOINT.appPageSize) {
						hasNextPage = false;
					}

					// 存在下一页，存储数据
					storage[type] = {
						hasNextPage: hasNextPage,
						nextPage: 2,
						result: data
					}

					console.log(storage[type].result);

					// 数据请求完成以后，通知 controller
					$rootScope.$broadcast('Game.Updated');

				})
				.error(function() {

					$rootScope.endPage = false;

				})

		}

		// 获取保存数据
		function getStorage() {

			// 解决异步加载数据没有完成
			if (storage[type] == undefined) {
				return false;
			}

			return storage[type].result;

		}

		// 获取更多数据
		function getMoreStorage() {

			// 为了解决一步加载的时候数据还没有加载完成  然后请求loadMore的时候  找不到数据
			if (storage[type] === undefined) {
				return false;
			}

			// 获取以前的数据
			var hasNextPage = storage[type].hasNextPage;
			var nextPage = storage[type].nextPage;
			var morestorageData = storage[type].result;

			console.log(morestorageData);

			$http.get(ApiUrl + type + '/' + nextPage + '?t=' + Date.parse(new Date()))
				.success(function(data) {

					if (data.length < API_ENDPOINT.appPageSize) {
						hasNextPage = false;
					}

					// 连接存储对象
					morestorageData = morestorageData.concat(data);

					console.log(morestorageData);

					if (data.length < API_ENDPOINT.appPageSize) {
						hasNextPage = false;
					}

					// 存在下一页，存储数据
					storage[type] = {
						hasNextPage: hasNextPage,
						nextPage: nextPage,
						result: morestorageData
					}

					// 数据请求完成以后，通知 controller
					$rootScope.$broadcast('Game.Updated');

				})
				.error(function() {

					$rootScope.endPage = false;

				})

			nextPage++;

		}

		function setStorage(cate_id) {

			// 动态设置分类 ID
			type = cate_id;

			// 重新调用接口页面
			this.getInitStorage();

		}

		// 判断是否有下一页
		function hasNextPage() {

			if (storage[type] === undefined) {
				return false;
			}

			return storage[type].hasNextPage;

		}

		return {
			// 获取第一页数据
			getStorage: getStorage,
			// 写入分类数据
			setStorage: setStorage,
			// 获取保存数据
			getInitStorage: getInitStorage,
			// 获取更多数据
			getMoreStorage: getMoreStorage,
			// 判断是否有下一页
			hasNextPage: hasNextPage
		}

	})
	.factory('AudioService', function($rootScope, $http, API_ENDPOINT) {

	// API 数据接口
	var ApiUrl = 'data/audio/list/',
		// 分类ID
		cateId = 1,
		// 显示多少条数据
		nextPage = 1,
		// 存储数据结构，包含了下一页、是否有下一页的属性
		storage = {};

	// 获取第一页数据
	function getInitStorage() {

		// 是否有下一页
		var hasNextPage = true;
		console.log(ApiUrl + nextPage);
		$http.get(ApiUrl + nextPage + '?t=' + Date.parse(new Date()))
			.success(function(data) {

				//不存在下一页
				if (data.length < API_ENDPOINT.audioPageSize) {
					hasNextPage = false;
				}

				// 存在下一页，存储数据
				storage[cateId] = {
					hasNextPage: hasNextPage,
					nextPage: 2,
					result: data
				}

				console.log(storage[cateId].result);

				// 数据请求完成以后，通知 controller
				$rootScope.$broadcast('Audio.Updated');

			})
			.error(function() {

				$rootScope.endPage = false;

			})

	}

	// 获取保存数据
	function getStorage() {

		// 解决异步加载数据没有完成
		if (storage[cateId] == undefined) {
			return false;
		}

		return storage[cateId].result;

	}

	// 获取更多数据
	function getMoreStorage() {

		// 为了解决一步加载的时候数据还没有加载完成  然后请求loadMore的时候  找不到数据
		if (storage[cateId] === undefined) {
			return false;
		}

		// 获取以前的数据
		var hasNextPage = storage[cateId].hasNextPage;
		var nextPage = storage[cateId].nextPage;
		var morestorageData = storage[cateId].result;

		console.log(morestorageData);

		$http.get(ApiUrl + nextPage + '?t=' + Date.parse(new Date()))
			.success(function(data) {

				// 连接存储对象
				morestorageData = morestorageData.concat(data);

				console.log(morestorageData)

				//不存在下一页
				if (data.length < API_ENDPOINT.audioPageSize) {
					hasNextPage = false;
				}

				// 存在下一页，存储数据
				storage[cateId] = {
					hasNextPage: hasNextPage,
					nextPage: nextPage,
					result: morestorageData
				}

				// 数据请求完成以后，通知 controller
				$rootScope.$broadcast('Audio.Updated');

			})
			.error(function() {

				$rootScope.endPage = false;

			})

		nextPage++;

	}

	function setStorage(cate_id) {

		// 动态设置分类 ID
		cateId = cate_id;

		// 重新调用接口页面
		this.getInitStorage();

	}

	// 判断是否有下一页
	function hasNextPage() {

		if (storage[cateId] === undefined) {
			return false;
		}

		return storage[cateId].hasNextPage;

	}

	return {
		// 获取第一页数据
		getStorage: getStorage,
		// 写入分类数据
		setStorage: setStorage,
		// 获取保存数据
		getInitStorage: getInitStorage,
		// 获取更多数据
		getMoreStorage: getMoreStorage,
		// 判断是否有下一页
		hasNextPage: hasNextPage
	}

})
